        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 24 <strong>control</strong><br>0,2,9,11,12,14,15,21,22,25,27,28,32,33,36,37,39,40,41,42,44,46,47,48';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 18 <br>3,4,5,6,7,10,13,16,17,19,23,26,29,30,35,45,49,50';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>20</strong> miembros: 9 <br>1,8,18,20,24,31,34,38,43';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 24 <strong>control</strong><br>0,2,9,11,12,14,15,21,22,25,27,28,32,33,36,37,39,40,41,42,44,46,47,48';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 18 <br>3,4,5,6,7,10,13,16,17,19,23,26,29,30,35,45,49,50';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>20</strong> miembros: 9 <br>1,8,18,20,24,31,34,38,43';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 24 <strong>control</strong><br>0,2,9,11,12,14,15,21,22,25,27,28,32,33,36,37,39,40,41,42,44,46,47,48';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 18 <br>3,4,5,6,7,10,13,16,17,19,23,26,29,30,35,45,49,50';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>20</strong> miembros: 9 <br>1,8,18,20,24,31,34,38,43';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 24 <strong>control</strong><br>0,2,9,11,12,14,15,21,22,25,27,28,32,33,36,37,39,40,41,42,44,46,47,48';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 18 <br>3,4,5,6,7,10,13,16,17,19,23,26,29,30,35,45,49,50';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>20</strong> miembros: 9 <br>1,8,18,20,24,31,34,38,43';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 24 <strong>control</strong><br>0,2,9,11,12,14,15,21,22,25,27,28,32,33,36,37,39,40,41,42,44,46,47,48';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 18 <br>3,4,5,6,7,10,13,16,17,19,23,26,29,30,35,45,49,50';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>20</strong> miembros: 9 <br>1,8,18,20,24,31,34,38,43';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 24 <strong>control</strong><br>0,2,9,11,12,14,15,21,22,25,27,28,32,33,36,37,39,40,41,42,44,46,47,48';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>19</strong> miembros: 18 <br>3,4,5,6,7,10,13,16,17,19,23,26,29,30,35,45,49,50';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260427 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>20</strong> miembros: 9 <br>1,8,18,20,24,31,34,38,43';}
}
